@@ -25,6 +25,7 @@ import (
 	"flag"
 	"fmt"
 	"io"
+	"log"
 	"os"
 	"os/exec"
 	"path"
@@ -476,8 +477,8 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 					for _, arg := range args {
 						fields = append(fields, recfile.Field{Name: "Cmd", Value: arg})
 					}
-					for _, e := range cmd.Env {
-						fields = append(fields, recfile.Field{Name: "Env", Value: e})
+					for _, env := range cmd.Env {
+						fields = append(fields, recfile.Field{Name: "Env", Value: env})
 					}
 					if exitErr != nil {
 						fields = append(fields, recfile.Field{
@@ -486,12 +487,36 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 						})
 					}
 					w := bufio.NewWriter(fdStderr)
-					_, err = recfile.NewWriter(w).WriteFields(fields...)
-					w.Flush()
-					fdStderr.Close()
+
+					var depInfo *DepInfo
+					fdDep, err = os.Open(fdDep.Name())
 					if err != nil {
+						goto Err
+					}
+					depInfo, err = depRead(fdDep)
+					fdDep.Close()
+					if err != nil {
+						goto Err
+					}
+					for _, dep := range depInfo.ifchanges {
+						fields = append(fields, recfile.Field{
+							Name:  "Ifchange",
+							Value: dep["Target"],
+						})
+					}
+					_, err = recfile.NewWriter(w).WriteFields(fields...)
+					if err != nil {
+						goto Err
+					}
+					err = w.Flush()
+				Err:
+					if err != nil {
+						log.Println(err)
 						os.Remove(logRecPath)
 					}
+					fdStderr.Close()
+				} else {
+					log.Println("can not open", logRecPath, ":", err)
 				}
 			}
 			lockRelease()
@@ -556,15 +581,6 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 		finished = time.Now()
 		runErr.Finished = &finished
 		if err != nil {
-			// Try to commit .rec anyway
-			if !NoSync {
-				fdDep.Sync()
-			}
-			os.Rename(fdDep.Name(), path.Join(redoDir, tgt+DepSuffix))
-			if !NoSync {
-				err = syncDir(redoDir)
-			}
-
 			exitErr = err.(*exec.ExitError)
 			runErr.Err = err
 			errs <- runErr
